@@ -227,7 +227,7 @@ class ServerState(Qt.QObject):
         self.scanID = 0
 
         #: (:obj:`list`<:obj:`str`>) timers
-        self.timers = None
+        self.timers = []
         #: (:obj:`str`) measurement group name
         self.mntgrp = None
         #: (:obj:`str`) door  device name
@@ -523,7 +523,10 @@ class ServerState(Qt.QObject):
 
         self.acplist = self.__getList("preselectedComponents")
         self.atlist = self.__getList("availableTimers")
-        self.description = self.__getList("componentDescription", True)
+        try:
+            self.description = self.__getList("componentDescription", True)
+        except Exception as e:
+            logger.error(str(e))
         self.ddsdirty = True
         self.mutedChannels = self.__getList("mutedChannels")
 
@@ -878,6 +881,33 @@ class ServerState(Qt.QObject):
                             break
                 return status
 
+    def isDoorRunning(self):
+        """ check if any door server is running
+
+        :returns: if any door running
+        :rtype: :obj:`bool`
+        """
+        if not self.__dp:
+            self.setServer()
+        status = False
+        if hasattr(self.__dp, "macroServer"):
+            ms = str(self.__dp.macroServer)
+            if ms:
+                if ':' not in ms and hasattr(self.__dp, "get_db_host"):
+                    ms = "%s:%s/%s" % (self.__dp.get_db_host(),
+                                       self.__dp.get_db_port(),
+                                       ms)
+
+                msp = self.__openProxy(ms)
+                doors = msp.doorList
+                for door in doors:
+                    dp = PyTango.DeviceProxy(door)
+                    if dp.state() == PyTango.DevState.RUNNING:
+
+                        status = True
+                        break
+        return status
+
     @classmethod
     def __openProxy(cls, server):
         """ creates device proxy
